@@ -9,6 +9,7 @@ how to add a step!
 """
 
 from typing import Dict, List, Type
+from mitosheet.step_performers.concat import ConcatStepPerformer
 from mitosheet.step_performers.drop_duplicates import DropDuplicatesStepPerformer
 from mitosheet.step_performers.import_steps.excel_import import ExcelImportStepPerformer
 from mitosheet.step_performers.step_performer import StepPerformer
@@ -33,7 +34,7 @@ from mitosheet.step_performers.graph_steps.graph import GraphStepPerformer
 from mitosheet.step_performers.graph_steps.graph_delete import GraphDeleteStepPerformer
 from mitosheet.step_performers.graph_steps.graph_duplicate import GraphDuplicateStepPerformer
 from mitosheet.step_performers.graph_steps.graph_rename import GraphRenameStepPerformer
-
+from mitosheet.step_performers.fill_na import FillNaStepPerformer
 
 # All steps must be listed in this variable. Note the Type annotation allows for
 # subtypes of the step performer to be passed
@@ -48,6 +49,8 @@ STEP_PERFORMERS: List[Type[StepPerformer]] = [
     ChangeColumnDtypeStepPerformer,
     ChangeColumnFormatStepPerformer,
     MergeStepPerformer,
+    ConcatStepPerformer,
+    FillNaStepPerformer,
     DeleteColumnStepPerformer,
     RenameColumnStepPerformer,
     SimpleImportStepPerformer,
@@ -73,11 +76,4 @@ EVENT_TYPE_TO_STEP_PERFORMER: Dict[str, Type[StepPerformer]] = {
 STEP_TYPE_TO_STEP_PERFORMER: Dict[str, Type[StepPerformer]] = {
     step_performer.step_type(): step_performer
     for step_performer in STEP_PERFORMERS
-}
-
-# A dictionary mapping step performers to their usage triggered feedback id
-STEP_TYPE_TO_USAGE_TRIGGERED_FEEDBACK_ID: Dict[str, str] = {
-    step_performer.step_type(): step_performer.step_type() + '_usage_triggered'
-    for step_performer in STEP_PERFORMERS
-}
-del STEP_TYPE_TO_USAGE_TRIGGERED_FEEDBACK_ID[BulkOldRenameStepPerformer.step_type()]
+}
\ No newline at end of file
